plumbery.polishers package
==========================

Submodules
----------

plumbery.polishers.spit module
------------------------------

.. automodule:: plumbery.polishers.spit
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: plumbery.polishers
    :members:
    :undoc-members:
    :show-inheritance:
